@@ -9,6 +9,7 @@ from  vhdl_build_system.vhdl_entity_class            import vhdl_entity
 from  vhdl_build_system.vhdl_merge_split_test_cases  import merge_test_case
 from  vhdl_build_system.generic_helper               import save_file, try_make_dir, cl_add_entity, join_str
 from  vhdl_build_system.vhdl_programm_list           import add_programm 
+from  vhdl_build_system.generic_helper               import vprint, extract_cl_arguments
 
 import argparse
 import numpy as np 
@@ -65,7 +66,7 @@ package {write_pgk} is
 
 {records}
 
-end {write_pgk};
+end package;
 
 package body {write_pgk} is
 
@@ -313,7 +314,7 @@ begin
 
 {connections}
 
-end Behavioral;
+end architecture;
 ---------------------------------------------------------------------------------------------------
     '''.format(
         includes=get_includes(),
@@ -426,7 +427,7 @@ DUT :  entity work.{et_name} {generic_str} port map(
 {ports}
     );
 
-end behavior;
+end architecture;
 ---------------------------------------------------------------------------------------------------
     '''.format(
   includes=get_includes(),
@@ -478,7 +479,8 @@ def make_test_bench_main_wrap(x):
     cl_add_entity(parser)
     parser.add_argument('--OutputPath', help='Path to where the test bench should be created',default="" ,required=True)
     parser.add_argument('--NumberOfRows', help='Number of Rows in the Autogenerated CSV Files',default="1000")
-    args = parser.parse_args(x[2:])
+    
+    args = extract_cl_arguments(parser= parser,x=x)
     make_test_bench_main(args.entity,args.NumberOfRows, args.OutputPath)
            
     URL = "https://github.com/RPeschke/fmake/raw/main/proto_build/empty_testbench.xlsm"
